
# 
#clear environment 
rm(list = ls()) 
cat("\014")  # ctrl+L

#packages 
library(dplyr)
library(readxl)
library(tidyverse)
library(lubridate)
library(stargazer)
library(sandwich)
library(lmtest)
library(robustbase)


my_data <- read_excel("/Users/fabian/Downloads/fama_factors.xls")
hf_returns <- read_excel("/Users/fabian/Downloads/HF_returns_11years.xlsx", col_names = TRUE)
benchmark <- read_excel("/Users/fabian/Downloads/benchmarks.xlsx", col_names = TRUE)



#combine 
my_data <- mutate(my_data, hf_returns)
my_data <- mutate(my_data, benchmark)


#create HF-rf column

my_data$HF_SRImrf<- my_data$HF_SRI - my_data$`risk-free`
my_data$HF_convmrf<- my_data$HF_conv - my_data$`risk-free`
my_data$MSCImrf <- my_data$msci_world - my_data$`risk-free`
my_data$globalESGmrf <- my_data$stoxx_global_esg_leaders - my_data$`risk-free`
my_data$HFImrf <- my_data$HFI - my_data$`risk-free`
my_data$longonlymrf <- my_data$long_only - my_data$`risk-free`
my_data$longshortmrf <- my_data$long_short - my_data$`risk-free`
my_data$difference<- my_data$HF_SRImrf-my_data$HF_convmrf
my_data$DJ_worldmrf<- my_data$DJ_world - my_data$`risk-free`

#only change the market factor/benchmark for different factor models
# benchmark: MSCImrf , globalESGmrf,  HFImrf, DJ_worldmrf
# for long-only regressions: HF_SRI_longonly  ~ longonlymrf 

#perform some regressions

setwd("/Users/fabian/Desktop")

model1<- lm(HF_SRImrf  ~ MSCImrf  , my_data)
model2<- lm(HF_SRImrf  ~ MSCImrf+ SMB + HML, my_data)
model3<- lm(HF_SRImrf  ~ MSCImrf + SMB + HML + momentum, my_data)

stargazer(model1, model2, model3, title= "fama french regression", style= "default", type = "html",
          out = "regression.doc" )

model11<- lm(HF_convmrf ~  MSCImrf  , my_data)
model22<- lm(HF_convmrf ~ MSCImrf + SMB + HML , my_data)
model33<- lm(HF_convmrf ~  MSCImrf + SMB + HML + momentum, my_data)

stargazer(model11, model22, model33, title= "fama french regression", style= "default", type = "html",
          out = "regression1.doc" )

modeldif1<- lm(difference ~  MSCImrf, my_data)
modeldif2<- lm(difference ~  MSCImrf  + SMB + HML, my_data)
modeldif3<- lm(difference ~  MSCImrf + SMB + HML + momentum, my_data)

stargazer(modeldif1, modeldif2, modeldif3, title= "fama french regression", style= "default", type = "html",
          out = "regressiondiff.doc" )

model_1HC <- coeftest(model1, vcov = vcovHC(model1, type="HC0"))
model_2HC <- coeftest(model2, vcov = vcovHC(model2, type="HC0"))
model_3HC <- coeftest(model3, vcov = vcovHC(model3, type="HC0"))
model_11HC <- coeftest(model11, vcov = vcovHC(model11, type="HC0"))
model_22HC <- coeftest(model22, vcov = vcovHC(model22, type="HC0"))
model_33HC <- coeftest(model33, vcov = vcovHC(model33, type="HC0"))
model_dif1HC <- coeftest(modeldif1, vcov = vcovHC(modeldif1, type="HC0"))
model_dif2HC <- coeftest(modeldif2, vcov = vcovHC(modeldif2, type="HC0"))
model_dif3HC <- coeftest(modeldif3, vcov = vcovHC(modeldif3, type="HC0"))

stargazer(model_1HC, model_2HC, model_3HC, title= "Fama_french risk factor model", style= "default", type = "html",
          out = "regression1.doc" )
stargazer(model_11HC, model_22HC, model_33HC, title= "Fama_french risk factor model", style= "default", type = "html",
          out = "regression2.doc" )
stargazer(model_dif1HC, model_dif2HC, model_dif3HC, title= "Fama_french risk factor model", style= "default", type = "html",
          out = "regression3.doc" )

coeftest(model_1, vcov = vcovHC(model_1, type = "HC0"))
coeftest(model_2, vcov = vcovHC(model_1, type = "HC0"))
coeftest(model_3, vcov = vcovHC(model_1, type = "HC0"))
coeftest(model_11, vcov = vcovHC(model_1, type = "HC0"))
coeftest(model_22, vcov = vcovHC(model_1, type = "HC0"))
coeftest(model_33, vcov = vcovHC(model_1, type = "HC0"))
coeftest(model_dif1, vcov = vcovHC(model_1, type = "HC0"))
coeftest(model_dif2, vcov = vcovHC(model_1, type = "HC0"))
coeftest(model_dif3, vcov = vcovHC(model_1, type = "HC0"))
# HC0 gives White’s estimator 
# alternaviely use "rob" after the lm funcion, lmrob

# look on shorter time-periods - pre crisis and corona pandemic 2020

#data new timeframe 
pre_crisis <- filter(my_data, Date >= "2017-01" & Date <="2019-12")
pre_crisis <- filter(my_data, Date >= "2013-01" & Date <="2019-12")

precrisis1<- lmrob(HF_SRImrf  ~ MSCImrf , pre_crisis)
precrisis2<- lmrob(HF_SRImrf  ~ MSCImrf + SMB + HML, pre_crisis)
precrisis3<- lmrob(HF_SRImrf  ~ MSCImrf  + SMB + HML + momentum, pre_crisis)


stargazer(precrisis1, precrisis2, precrisis3, title= "fama french regression", style= "default", type = "html",
          out = "regression1.doc" )

precrisis11<- lmrob(HF_convmrf ~ MSCImrf , pre_crisis)
precrisis22<- lmrob(HF_convmrf ~ MSCImrf + SMB + HML , pre_crisis)
precrisis33<- lmrob(HF_convmrf ~ MSCImrf  + SMB + HML + momentum, pre_crisis)

stargazer(precrisis11, precrisis22, precrisis33, title= "fama french regression", style= "default", type = "html",
          out = "regression2.doc" )

precrisisdif1<- lmrob(difference ~ MSCImrf, pre_crisis)
precrisisdif2<- lmrob(difference ~ MSCImrf + SMB + HML, pre_crisis)
precrisisdif3<- lmrob(difference ~ MSCImrf + SMB + HML + momentum, pre_crisis)

stargazer(precrisisdif1, precrisisdif2, precrisisdif3, title= "fama french regression", style= "default", type = "html",
          out = "regressiondiff.doc" )


# create a new timeframe for regression analysis 
corona_period <- subset(my_data, Date>"2019-12")

corona1<- lmrob(HF_SRImrf  ~ MSCImrf , corona_period)
corona2<- lmrob(HF_SRImrf  ~ MSCImrf  + SMB + HML, corona_period)
corona3<- lmrob(HF_SRImrf  ~ MSCImrf  + SMB + HML + momentum, corona_period)


stargazer(corona1, corona2, corona3, title= "fama french regression", style= "default", type = "html",
          out = "regression.doc" )

corona11<- lmrob(HF_convmrf ~ MSCImrf, corona_period)
corona22<- lmrob(HF_convmrf ~ MSCImrf + SMB + HML , corona_period)
corona33<- lmrob(HF_convmrf ~ MSCImrf + SMB + HML + momentum, corona_period)

stargazer(corona11, corona22, corona33, title= "fama french regression", style= "default", type = "html",
          out = "regression1.doc" )

coronadif1<- lmrob(difference ~ MSCImrf, corona_period)
coronadif2<- lmrob(difference ~ MSCImrf + SMB + HML, corona_period)
coronadif3<- lmrob(difference ~ MSCImrf+ SMB + HML + momentum, corona_period)

stargazer(coronadif1, coronadif2, coronadif3, title= "fama french regression", style= "default", type = "html",
          out = "regressiondiff.doc" )


# sovereign debt crisis  
debtcrisis_period <- subset(my_data, Date<="2012-12")


debtcrisis1<- lmrob(HF_SRImrf  ~ MSCImrf  , debtcrisis_period)
debtcrisis2<- lmrob(HF_SRImrf  ~ MSCImrf   + SMB + HML, debtcrisis_period)
debtcrisis3<- lmrob(HF_SRImrf  ~ MSCImrf + SMB + HML + momentum, debtcrisis_period)


stargazer(debtcrisis1, debtcrisis2, debtcrisis3, title= "fama french regression", style= "default", type = "html",
          out = "regression.doc" )

debtcrisis11<- lmrob(HF_convmrf ~ MSCImrf, debtcrisis_period)
debtcrisis22<- lmrob(HF_convmrf ~ MSCImrf + SMB + HML , debtcrisis_period)
debtcrisis33<- lmrob(HF_convmrf ~ MSCImrf + SMB + HML + momentum, debtcrisis_period)

stargazer(debtcrisis11, debtcrisis22, debtcrisis33, title= "fama french regression", style= "default", type = "html",
          out = "regression1.doc" )

debtcrisisdif1<- lmrob(difference ~ MSCImrf, debtcrisis_period)
debtcrisisdif2<- lmrob(difference ~ MSCImrf + SMB + HML, debtcrisis_period)
debtcrisisdif3<- lmrob(difference ~ MSCImrf+ SMB + HML + momentum, debtcrisis_period)

stargazer(debtcrisisdif1, debtcrisisdif2, debtcrisisdif3, title= "fama french regression", style= "default", type = "html",
          out = "regressiondiff.doc" )




