
#clear environment 
rm(list = ls()) 
cat("\014")  # ctrl+L

#packages 
library(dplyr)
library(readxl)
library(tidyverse)
library(lubridate)
library(stargazer)
library(sandwich)
library(lmtest)
library(robustbase)


#####own data by Eurekahedge 

data_funds <- read_excel("/Users/fabian/Downloads/data_funds.xlsx", col_names = TRUE)


#descriptive statistics 
# build the HF summary statitics table
#filter only after ESG HF 

data_HFSRI<- subset(data_funds, ESG==1)
summary(data_HFSRI)

sd(data_HFSRI$age)
sd(data_HFSRI$assets)
sd(data_HFSRI$years)
sd(data_HFSRI$management_fee)
sd(data_HFSRI$performance_fee)
sd(data_HFSRI$leveraged)
sd(data_HFSRI$`dividend_ policy`)
sd(data_HFSRI$HWM)
sd(data_HFSRI$lock_up)
sd(data_HFSRI$penalty)

data_HFnotSRI<- subset(data_funds, ESG==0)
summary(data_HFnotSRI)
sd(data_HFnotSRI$age)
sd(data_HFnotSRI$assets)
sd(data_HFnotSRI$years)
sd(data_HFnotSRI$management_fee)
sd(data_HFnotSRI$performance_fee)
sd(data_HFnotSRI$leveraged)
sd(data_HFnotSRI$`dividend_ policy`)
sd(data_HFnotSRI$HWM)
sd(data_HFnotSRI$lock_up)
sd(data_HFnotSRI$penalty)


#Conduct two-sample t-test
#compare the means of two samples with unequal variances = Welch t-test 

#Null Hypothesis: There is no difference between the mean of two samples
#Alternative Hypothesis: There is difference between the mean of two samples

var(data_HFSRI$assets)
var(data_HFnotSRI$assets)
var(data_HFSRI$years)
var(data_HFnotSRI$years)
var(data_HFSRI$return)
var(data_HFnotSRI$return)
var(data_HFSRI$management_fee)
var(data_HFnotSRI$management_fee)
var(data_HFSRI$performance_fee)
var(data_HFnotSRI$performance_fee)
var(data_HFSRI$leveraged)
var(data_HFnotSRI$leveraged)
var(data_HFSRI$`dividend_ policy`)
var(data_HFnotSRI$`dividend_ policy`)
var(data_HFSRI$HWM)
var(data_HFnotSRI$HWM)
var(data_HFSRI$lock_up)
var(data_HFnotSRI$lock_up)
var(data_HFSRI$penalty)
var(data_HFnotSRI$penalty)

# the variances are unequal. 

t.test(data_HFSRI$assets,data_HFnotSRI$assets,var.equal = F)
t.test(data_HFSRI$years,data_HFnotSRI$years,var.equal = F)
t.test(data_HFSRI$return,data_HFnotSRI$return,var.equal = F)
t.test(data_HFSRI$management_fee,data_HFnotSRI$management_fee,var.equal = F)
t.test(data_HFSRI$performance_fee,data_HFnotSRI$performance_fee,var.equal = F)
t.test(data_HFSRI$leveraged,data_HFnotSRI$leveraged,var.equal = F)
t.test(data_HFSRI$`dividend_ policy`,data_HFnotSRI$`dividend_ policy`,var.equal = F)
t.test(data_HFSRI$HWM,data_HFnotSRI$HWM,var.equal = F)
t.test(data_HFSRI$lock_up,data_HFnotSRI$lock_up,var.equal = F)
t.test(data_HFSRI$penalty,data_HFnotSRI$penalty,var.equal = F)



#correlation 
data_fung <- read_excel("/Users/fabian/Downloads/Fung_factors.xlsx", col_names = TRUE)
require(Hmisc)

# 8 factors Fung
cor.0 = rcorr(x = as.matrix(data_fung[, c(12, 21:22, 15:16, 18, 7:9, 19)]), y = NULL,
              type ="pearson")

print(cor.0)

data_hfstrategies<- read_excel("/Users/fabian/Downloads/HF_returns_11years.xlsx", col_names = TRUE)
#hedge fund strategies and benchmarks
cor.1 = rcorr(x = as.matrix(data_hfstrategies[, c(1:6)]), y = NULL,
              type ="pearson")
print(cor.1)



## model of Fung/Hsieh


data_fung <- read_excel("/Users/fabian/Downloads/Fung_factors.xlsx", col_names = TRUE)

benchmark <- read_excel("/Users/fabian/Downloads/benchmarks.xlsx", col_names = TRUE)
data_fung <- mutate(data_fung, benchmark)


# original 7 factor model 
# change the original market factor SNP to other benchmarks like msci_world or HFI or stoxx_global_esg_leaders
#change dependend variable from SRI_excess to HF_excess 

model_1 <- lm(SRI_excess ~ msci_world + Size_Spread + DGS10 + DBAAMDGS10 + PTFSBD + PTFSFX + PTFSCOM, data = data_fung)
summary(model_1)

#include the 8-factor for emerging countries 
model_2 <- lm(SRI_excess ~ msci_world + Size_Spread + DGS10 + DBAAMDGS10 + PTFSBD + PTFSFX + PTFSCOM + Emerging, data = data_fung)

# HF-conventional 
model_3 <- lm(HF_excess ~ msci_world + Size_Spread + DGS10 + DBAAMDGS10 + PTFSBD + PTFSFX + PTFSCOM, data = data_fung)
model_4 <- lm(HF_excess ~ msci_world + Size_Spread + DGS10 + DBAAMDGS10 + PTFSBD + PTFSFX + PTFSCOM + Emerging, data = data_fung)

stargazer(model_1, model_2, model_3, model_4, title= "Fung & Hsieh hedge fund risk factor model", style= "default", type = "html",
          out = "regression.doc" )


# robust standard errors
library(sandwich)
coeftest(model_1, vcov = vcovHC(model_1))
coeftest(model_1, vcov = vcovHC(model_1, type = "HC0"))
# or lmrob

model_1 <- lmrob(SRI_excess ~ msci_world + Size_Spread + DGS10 + DBAAMDGS10 + PTFSBD + PTFSFX + PTFSCOM, data = data_fung)
model_2 <- lmrob(SRI_excess ~ msci_world + Size_Spread + DGS10 + DBAAMDGS10 + PTFSBD + PTFSFX + PTFSCOM + Emerging, data = data_fung)
model_3 <- lmrob(HF_excess ~ msci_world + Size_Spread + DGS10 + DBAAMDGS10 + PTFSBD + PTFSFX + PTFSCOM, data = data_fung)
model_4 <- lmrob(HF_excess ~ msci_world + Size_Spread + DGS10 + DBAAMDGS10 + PTFSBD + PTFSFX + PTFSCOM + Emerging, data = data_fung)




# create a new timeframe for regression analysis 
last4year_period <- subset(data_fung, Date>"2016-12")
model_1 <- lm(SRI_excess ~ msci_world  + Size_Spread + DGS10 + DBAAMDGS10 + PTFSBD + PTFSFX + PTFSCOM, data = last4year_period)
model_2 <- lm(SRI_excess ~ msci_world + Size_Spread + DGS10 + DBAAMDGS10 + PTFSBD + PTFSFX + PTFSCOM + Emerging, data = last4year_period)
model_3 <- lm(HF_excess ~ msci_world + Size_Spread + DGS10 + DBAAMDGS10 + PTFSBD + PTFSFX + PTFSCOM, data = last4year_period)
model_4 <- lm(HF_excess ~ msci_world  + Size_Spread + DGS10 + DBAAMDGS10 + PTFSBD + PTFSFX + PTFSCOM + Emerging, data = last4year_period)



#own multifactor model 
# change from SRI_excess to HF_excess 
# change to HF_SRI_longonly HF_conv_longonly HF_SRI_longshort HF_conv_longshort
model_1 <- lm(SRI_excess ~ msci_world + HML + momentum + Size_Spread + DGS10 + DBAAMDGS10 + PTFSBD + PTFSFX + PTFSCOM , data = data_fung)
model_2 <- lm(SRI_excess~ msci_world  + HML + momentum + Size_Spread + DGS10 + DBAAMDGS10 + PTFSBD + PTFSFX + PTFSCOM  + Emerging, data = data_fung)
model_3 <- lm(HF_excess ~ msci_world + HML + momentum + Size_Spread + DGS10 + DBAAMDGS10 + PTFSBD + PTFSFX + PTFSCOM , data = data_fung)
model_4 <- lm(HF_excess~ msci_world + HML + momentum + Size_Spread + DGS10 + DBAAMDGS10 + PTFSBD + PTFSFX + PTFSCOM  + Emerging, data = data_fung)

stargazer(model_1, model_2, title= "hedge fund multi-factor model", style= "default", type = "html",
          out = "regression1.doc" )

stargazer(model_1, model_2, model_3, model_4, title= "hedge fund multi-factor model", style= "default", type = "html",
          out = "regression.doc" )




library(lmtest)
#test on robust standard errors
bptest(model_1)
bptest(model_2)
bptest(model_3)
bptest(model_4)
#Since the p-value of ...  is much more than 5%, 
#I can't reject the null hypothesis that the data are not homoscedastic. 
#Hence the regression analysis cannot be flawed by heteroskedasticity.

#regression analysis with estimates of the standard errors of the estimated coefficient robust
# to heteroscedasticity, using the sandwich package with his vcov() function

vcov = vcovHC(model_1, type="HC0")
print(vcov)

model_1HC <- coeftest(model_1, vcov = vcovHC(model_1))
model_2HC <- coeftest(model_2, vcov = vcovHC(model_2))
model_3HC <- coeftest(model_3, vcov = vcovHC(model_3))
model_4HC <- coeftest(model_4, vcov = vcovHC(model_4))
# by default type "HC3"
model_1HC <- coeftest(model_1, vcov = vcovHC(model_1, type="HC0"))
model_2HC <- coeftest(model_2, vcov = vcovHC(model_2, type="HC0"))
model_3HC <- coeftest(model_3, vcov = vcovHC(model_3, type="HC0"))
model_4HC <- coeftest(model_4, vcov = vcovHC(model_4, type="HC0"))

stargazer(model_1HC, model_2HC, model_3HC, model_4HC, title= "Fung & Hsieh hedge fund risk factor model", style= "default", type = "html",
          out = "regression.doc" )

print(model_1HC)


