# Propensity Score Matching

# http://sekhon.berkeley.edu/matching/
  

#clear environment 
rm(list = ls()) 
cat("\014")  # ctrl+L

install.packages("Matching")
install.packages("rbounds")
install.packages("rgenoud")
library("Matching")
library("rbounds")
library("rgenoud")


#own data by Eurekahedge 

data_funds_11years <- read_excel("/Users/fabian/Downloads/data_funds.xlsx", col_names = TRUE)
#data_funds_4years <- read_excel("/Users/fabian/Downloads/data_funds_PSM4years.xlsx", col_names = TRUE) # no signficant findings

attach(data_funds_11years)
#attach(data_funds_4years) 


# Defining variables (Tr is treatment, Y is outcome, X are independent variables)
# X can be: assets, years, management_fee, performance_fee, leveraged, dividend_policy, HWM, lock_up and penalty 
Tr <- cbind(ESG)
Y <- cbind(return)
X <- cbind(assets, years) #1 # equation 12 variable
# test different variables 
X <- cbind(assets, years, HWM) #2 lowest p-value  
X <- cbind(assets, years, leveraged, HWM) #3

X <- cbind(assets, years, management_fee, performance_fee,HWM) #4

X <- cbind(assets, years,leveraged, HWM) #5
X <- cbind(assets, years, management_fee, performance_fee,leveraged, HWM) #6 # equation 13 variable

# change to different variables 
var1 <- years


# Descriptive statistics
summary (Tr)
summary(Y)
summary(X)

#estimate the propensity model before "Match"
# Propensity score model : First Step 
glm1 <- glm(Tr ~ X, family=binomial(link = "probit"), data=data_funds_11years)
summary(glm1)

#interpretation of the negative sign for #1:funds with higher assets and more years are less likely
# in the treated group. only years is significant. 

# Average treatment on the treated effect: Second Step Matching on the propensity scores. 
rr1 <- Match(Y = Y, Tr = Tr, X = glm1$fitted)   
summary(rr1)

# interpretation: 
 # Estimate for #3: 0.0014578 -> if ESG hedge fund, than you have 0,15% more return each month. but not significant

#Average treatment on the treated effect (ATT) or Average treatment effect (ATE) with M equal 1 meaning that 
# each control observation is used once.
#ATT -  average of the slope over the subset of the population for hedge funds pursing SRI strategies. 
#ATE - average of the slope over the entire population of hedge funds.
rr2 <- Match(Y = Y, Tr = Tr, X = glm1$fitted, estimand = "ATT", M = 1, ties = FALSE, replace = TRUE) # see rr1 above this is done by default  
rr3 <- Match(Y = Y, Tr = Tr, X = glm1$fitted, estimand = "ATE", M = 1, ties = FALSE, replace = TRUE) # new method with ATE

#M = The ratio of treated to control observations , ratio is set by default =1 
# replace = default is true if matching is done with replacement 
# replace=FALSE, then Some control observations will not be matched, because there are more control observations than treated obs. 
# ties also by default = true 

summary(rr2)
summary(rr3) # in many cases more significant values ; Estimate for #3 is now significant 

# Check the balancing property
MatchBalance(Tr ~ X, match.out = rr1, nboots=0, data=data_funds_11years)
# qq-plot after matching
qqplot(var1[rr1$index.control], var1[rr1$index.treated])
abline(coef = c(0, 1), col = 2)

# qq-plot before matching
qqnorm(data_funds_11years$years)
qqline(data_funds_11years$years, col= 'red')
# since the points don't fall on the red line, the data is not normally distriubted. 

# normality test
shapiro.test(data_funds_11years$years)
# p-value is less than 0,05, reject the null hypothesis -> the data is not normally distributed.

# the red line indicates a perfect match 
# we see that matches are better for younger ages. the goal is to get the matches as close as possible
# to the red 45 degree line.

# Genetic matching , matching results are probably better
gen1 <- GenMatch(Tr = Tr, X = X, BalanceMatrix = X, pop.size = 10)
mgen1 <- Match(Y = Y, Tr = Tr, X = X, Weight.matrix = gen1)
MatchBalance(Tr ~ X, data = data_funds_11years, match.out = mgen1, nboots = 1000)
summary(mgen1)
# nboots = 0 - no bootstraps are done
# 500 nboots (preferably 1000) are recommended for better p values
# match.out option is used to provide the output object from the previous Match which is in my case: gen1
# MatchBalance will provide balance statistics for both before and after matching, 

# Sensitivity tests
psens(mgen1, Gamma=1.7, GammaInc=.05)
hlsens(mgen1, Gamma=1.7, GammaInc=.05, .1)

psens(rr3, Gamma=1.7, GammaInc=.05)
hlsens(rr3, Gamma=1.7, GammaInc=.05, .1)
