
#clear environment 
rm(list = ls()) 
cat("\014")  # ctrl+L

#packages 
library(dplyr)
library(readxl)
library(tidyverse)
library(lubridate)
library(stargazer)
library(sandwich)
library(lmtest)
library(robustbase)



rm(list = ls()) 
cat("\014")  # ctrl+L
#####own data by Eurekahedge 

data_funds <- read_excel("/Users/fabian/Downloads/robustness_data_funds.xlsx", col_names = TRUE)

#descriptive statistics 
# build the HF summary statitics table
#filter only after ESG HF 

data_HFSRI<- subset(data_funds, ESG==1)
summary(data_HFSRI)

sd(data_HFSRI$age)
sd(data_HFSRI$assets)

sd(data_HFSRI$management)
sd(data_HFSRI$performance)
sd(data_HFSRI$leveraged)
sd(data_HFSRI$dividend)
sd(data_HFSRI$HWM)
sd(data_HFSRI$lock_up)
sd(data_HFSRI$penalty)

data_HFnotSRI<- subset(data_funds, ESG==0)
summary(data_HFnotSRI)
sd(data_HFnotSRI$age)
sd(data_HFnotSRI$assets)

sd(data_HFnotSRI$management)
sd(data_HFnotSRI$performance)
sd(data_HFnotSRI$leveraged)
sd(data_HFnotSRI$dividend)
sd(data_HFnotSRI$HWM)
sd(data_HFnotSRI$lock_up)
sd(data_HFnotSRI$penalty)



# 4-factor model

my_data <- read_excel("/Users/fabian/Downloads/fama_factors.xls")
hf_returns <- read_excel("/Users/fabian/Downloads/robustness_long_short.xlsx", col_names = TRUE)
benchmark <- read_excel("/Users/fabian/Downloads/benchmarks_4years.xlsx", col_names = TRUE)

# cut the time for the last 4years 2017-2020 
my_data<- subset(my_data, Date>"2016-12")


#combine 
my_data <- mutate(my_data, hf_returns)
my_data <- mutate(my_data, benchmark)


#create HF-rf column

my_data$HF_SRImrf<- my_data$SRI - my_data$`risk-free`
my_data$HF_convmrf<- my_data$non_SRI - my_data$`risk-free`
my_data$MSCImrf <- my_data$msci_world - my_data$`risk-free`
my_data$globalESGmrf <- my_data$stoxx_global_esg_leaders - my_data$`risk-free`
my_data$HFImrf <- my_data$HFI - my_data$`risk-free`
my_data$difference<- my_data$HF_SRImrf-my_data$HF_convmrf
my_data$msci_kld400mrf <- my_data$msci_kld400-my_data$`risk-free`
my_data$FTSE4Good_developedmrf <- my_data$FTSE4Good_developed - my_data$`risk-free`
my_data$Hedgefundindexmrf <- my_data$Hedgefundindex - my_data$`risk-free`
my_data$longshortmrf <- my_data$longshort - my_data$`risk-free`


#only change the market factor/benchmark for different factor models
# globalESGmrf, msci_kld400mrf, FTSE4Good_developedmrf -- retrieved from Thomson Reuters
# Hedgefundindexmrf, longshortmrf -- retrieved from CreditSuisse 


#perform some regressions

setwd("/Users/fabian/Desktop")

model1<- lmrob(HF_SRImrf  ~ FTSE4Good_developedmrf  , my_data)
model2<- lmrob(HF_SRImrf  ~ FTSE4Good_developedmrf+ SMB + HML, my_data)
model3<- lmrob(HF_SRImrf  ~ FTSE4Good_developedmrf + SMB + HML + momentum, my_data)

stargazer(model1, model2, model3, title= "fama french regression", style= "default", type = "html",
          out = "regression.doc" )

model11<- lmrob(HF_convmrf ~  FTSE4Good_developedmrf  , my_data)
model22<- lmrob(HF_convmrf ~ FTSE4Good_developedmrf + SMB + HML , my_data)
model33<- lmrob(HF_convmrf ~  FTSE4Good_developedmrf + SMB + HML + momentum, my_data)

stargazer(model11, model22, model33, title= "fama french regression", style= "default", type = "html",
          out = "regression1.doc" )

modeldif1<- lmrob(difference ~  FTSE4Good_developedmrf, my_data)
modeldif2<- lmrob(difference ~  FTSE4Good_developedmrf + SMB + HML, my_data)
modeldif3<- lmrob(difference ~  FTSE4Good_developedmrf + SMB + HML + momentum, my_data)

stargazer(modeldif1, modeldif2, modeldif3, title= "fama french regression", style= "default", type = "html",
          out = "regressiondiff.doc" )


# look on corona pandemic 2020

# create a new timeframe for regression analysis 
corona_period <- subset(my_data, Date>"2019-12")

corona1<- lmrob(HF_SRImrf  ~ FTSE4Good_developedmrf , corona_period)
corona2<- lmrob(HF_SRImrf  ~ FTSE4Good_developedmrf + SMB + HML, corona_period)
corona3<- lmrob(HF_SRImrf  ~ FTSE4Good_developedmrf + SMB + HML + momentum, corona_period)


stargazer(corona1, corona2, corona3, title= "fama french regression", style= "default", type = "html",
          out = "regression.doc" )

corona11<- lmrob(HF_convmrf ~ FTSE4Good_developedmrf, corona_period)
corona22<- lmrob(HF_convmrf ~ FTSE4Good_developedmrf + SMB + HML , corona_period)
corona33<- lmrob(HF_convmrf ~ FTSE4Good_developedmrf + SMB + HML + momentum, corona_period)

stargazer(corona11, corona22, corona33, title= "fama french regression", style= "default", type = "html",
          out = "regression1.doc" )

coronadif1<- lmrob(difference ~ FTSE4Good_developedmrf, corona_period)
coronadif2<- lmrob(difference ~ FTSE4Good_developedmrf + SMB + HML, corona_period)
coronadif3<- lmrob(difference ~ FTSE4Good_developedmrf + SMB + HML + momentum, corona_period)

stargazer(coronadif1, coronadif2, coronadif3, title= "fama french regression", style= "default", type = "html",
          out = "regressiondiff.doc" )




## model of Fsungh Hsieh


data_fung <- read_excel("/Users/fabian/Downloads/Fung_factors_robustness.xlsx", col_names = TRUE)

benchmark <- read_excel("/Users/fabian/Downloads/benchmarks_4years.xlsx", col_names = TRUE)
data_fung <- mutate(data_fung, benchmark)


# original 7 factor model 
# change the original market factor SNP to other benchmarks like msci_world, HFI,  stoxx_global_esg_leaders,
# globalESGmrf, msci_kld400, FTSE4Good_developed
# Hedgefundindex, longshort -- retrieved from CreditSuisse 

#change dependend variable from SRI_excess to HF_excess 

model_1 <- lmrob(SRI_excess ~ longshort + Size_Spread + DGS10 + DBAAMDGS10 + PTFSBD + PTFSFX + PTFSCOM, data = data_fung)
summary(model_1)

#include the 8-factor for emerging countries 
model_2 <- lmrob(SRI_excess ~ longshort + Size_Spread + DGS10 + DBAAMDGS10 + PTFSBD + PTFSFX + PTFSCOM + Emerging, data = data_fung)

model_3 <- lmrob(HF_excess ~ longshort + Size_Spread + DGS10 + DBAAMDGS10 + PTFSBD + PTFSFX + PTFSCOM, data = data_fung)
model_4 <- lmrob(HF_excess ~ longshort + Size_Spread + DGS10 + DBAAMDGS10 + PTFSBD + PTFSFX + PTFSCOM + Emerging, data = data_fung)

stargazer(model_1, model_2, model_3, model_4, title= "Fung & Hsieh hedge fund risk factor model", style= "default", type = "html",
          out = "regression.doc" )


#own multifactor model - change form SRI_excess to HF_excess 
# change to HF_SRI_longonly HF_conv_longonly HF_SRI_longshort HF_conv_longshort
model_1 <- lm(SRI_excess ~ longshort + HML + momentum + Size_Spread + DGS10 + DBAAMDGS10 + PTFSBD + PTFSFX + PTFSCOM , data = data_fung)
model_2 <- lm(SRI_excess~ longshort  + HML + momentum + Size_Spread + DGS10 + DBAAMDGS10 + PTFSBD + PTFSFX + PTFSCOM  + Emerging, data = data_fung)
model_3 <- lm(HF_excess ~ longshort + HML + momentum + Size_Spread + DGS10 + DBAAMDGS10 + PTFSBD + PTFSFX + PTFSCOM , data = data_fung)
model_4 <- lm(HF_excess~ longshort + HML + momentum + Size_Spread + DGS10 + DBAAMDGS10 + PTFSBD + PTFSFX + PTFSCOM  + Emerging, data = data_fung)

stargazer(model_1, model_2, title= "hedge fund multi-factor model", style= "default", type = "html",
          out = "regression1.doc" )

stargazer(model_1, model_2, model_3, model_4, title= "hedge fund multi-factor model", style= "default", type = "html",
          out = "regression.doc" )


model_1HC <- coeftest(model_1, vcov = vcovHC(model_1, type="HC0"))
model_2HC <- coeftest(model_2, vcov = vcovHC(model_2, type="HC0"))
model_3HC <- coeftest(model_3, vcov = vcovHC(model_3, type="HC0"))
model_4HC <- coeftest(model_4, vcov = vcovHC(model_4, type="HC0"))

summary(model_1HC)

stargazer(model_1HC, model_2HC, model_3HC, model_4HC, title= "own multi-factor model", style= "default", type = "html",
          out = "regression.doc" )


library(lmtest)
#test on robust standard errors
bptest(model_1)
bptest(model_2)

vcov = vcovHC(model_1, type="HC0")
print(vcov)







